#/bin/ksh

# Globals
PATH="/mount/usr/bp/bin:$PATH:/bin:/usr/bin:/sbin:/usr/sbin:."
CCB_FILE="/mount/usr/bp/bpinit/ccb-tmp.ini"
LOG_FILE="/mount/usr/bp/logs.dir/PCPTest.log"
TMP_LOG="/tmp/tmp.out"
TXT_LINE="----------------------------------------"
STATUS=0

# Functions
field() { # n [sep] where n is field number and sep is field seperators

( [ -n "$2" ] && IFS="$2"
while read F1 F2 F3 F4 F5 F6 F7 F8 F9
do
    case "$1" in
        1) echo -e "$F1";; 2) echo -e "$F2";; 3) echo -e "$F3";; 4) echo -e "$F4";;
        5) echo -e "$F5";; 6) echo -e "$F6";; 7) echo -e "$F7";; 8) echo -e "$F8";;
        9) echo -e "$F9";; *);;
    esac
done
unset F1 F2 F3 F4 F5 F6 F7 F8 F9
)
}
export field;

# Do Title
echo -e $TXT_LINE > $LOG_FILE
echo -e     "           Bare Metal (TM)" >> $LOG_FILE
echo -e     "              Test Report" >> $LOG_FILE
echo -e $TXT_LINE >> $LOG_FILE
echo -e " " >> $LOG_FILE

# Tests
SUCCES="Success!"
FAILED="Failed!"
STARTT="<** Testing Bare Metal Settings **>"
PHASE1=" ** Phase 1 - Test for Hard Drive .....\c"
PHASE2=" ** Phase 2 - Test for Network ........\c"
PHASE3=" ** Phase 3 - Ping server by name .....\c" 
PHASE4=" ** Phase 4 - Ping server by IP .......\c"
PHASE5=" ** Phase 5 - Test Connect BP Server ..\c"
FINISH="Completed all tests ... \c"

# Start Test
echo -e "$STARTT"

# Phase 1 - Find the hard drive
echo -e "$PHASE1"
echo -e "$PHASE1" > $TMP_LOG
ISSCSI=`sed -n /IsScsi=/p $CCB_FILE|field 2 =`
if [ -z "$ISSCSI" ]; then
	echo -e "$FAILED"
	echo -e "$FAILED" >> $TMP_LOG
	STATUS=1
else
	if [ -z $1 ]; then
		if [ "$ISSCSI" = "Yes" ]; then
			DRIVENAME="/dev/sda"
		else
			DRIVENAME="/dev/hda"
		fi
	else
		DRIVENAME=$1
	fi

	echo -e "\tHard Drive....: $DRIVENAME" >> $LOG_FILE
	dd if=$DRIVENAME of=/dev/null bs=1k count=4 > /dev/null 2>&1 3>&1
	if [ "$?" != 0 ]; then
		echo -e "$FAILED"
		echo -e "$FAILED" >> $TMP_LOG
		STATUS=1
	else
		echo -e "$SUCCES"
		echo -e "$SUCCES" >> $TMP_LOG
	fi
fi

# Phase 2 - Find the network card
echo -e "$PHASE2"
echo -e "$PHASE2" >> $TMP_LOG
mv /dev/console /dev/console2
NETCARD=`ifconfig 2>&1|sed -n /eth/p |field 1`
mv /dev/console2 /dev/console
if [ -z "$NETCARD" ]; then
	echo -e "$FAILED"
	echo -e "$FAILED" >> $TMP_LOG
	STATUS=1
else
	echo -e "\tNet Adapter...: $NETCARD" >> $LOG_FILE
	echo -e "$SUCCES"
	echo -e "$SUCCES" >> $TMP_LOG
fi

# Phase 3 - Ping server by name
echo -e "$PHASE3"
echo -e "$PHASE3" >> $TMP_LOG
BPSERVERNAME=`sed -n /BpServer=/p $CCB_FILE|field 2 =`
if [ -z "$BPSERVERNAME" ]; then
	echo -e "$FAILED"
	echo -e "$FAILED" >> $TMP_LOG
	STATUS=1
else
	echo -e "\tServer Name...: $BPSERVERNAME" >> $LOG_FILE
	ping -c 1 $BPSERVERNAME > /dev/null 2>&1
	if [ "$?" != 0 ]; then
		echo -e "$FAILED"
		echo -e "$FAILED" >> $TMP_LOG
		STATUS=1
	else
		echo -e "$SUCCES"
		echo -e "$SUCCES" >> $TMP_LOG
	fi
fi

# Phase 4 - Ping the server by IP Address
echo -e "$PHASE4"
echo -e "$PHASE4" >> $TMP_LOG
BPSERVERIP=`sed -n /BpServerIP=/p $CCB_FILE|field 2 =`
if [ -z "$BPSERVERIP" ]; then
	echo -e "$FAILED"
	echo -e "$FAILED" >> $TMP_LOG
	STATUS=1
else
	echo -e "\tServer IP.....: $BPSERVERIP" >> $LOG_FILE
	ping -c 1 $BPSERVERIP > /dev/null 2>&1 3>&1
	if [ "$?" != 0 ]; then
		echo -e "$FAILED"
		echo -e "$FAILED" >> $TMP_LOG
		STATUS=1
	else
		echo -e "$SUCCES"
		echo -e "$SUCCES" >> $TMP_LOG
	fi
fi

# Phase 5 - Test that the BP server port is open
echo -e "$PHASE5"
echo -e "$PHASE5" >> $TMP_LOG
bptest $BPSERVERNAME > /dev/null 2>&1 3>&1
if [ "$?" != 0 ]; then
	echo -e "$FAILED"
	echo -e "$FAILED" >> $TMP_LOG
	STATUS=1
else
	echo -e "$SUCCES"
	echo -e "$SUCCES" >> $TMP_LOG
fi

# Finish
echo -e "$FINISH"
echo -e " " >> $LOG_FILE
cat $TMP_LOG >> $LOG_FILE
rm $TMP_LOG
echo -e "$FINISH" >> $LOG_FILE
if [ "$STATUS" = 0 ]; then
	echo -e "$SUCCES"
	echo -e "$SUCCES" >> $LOG_FILE
else
	echo -e "$FAILED"
	echo -e "$FAILED" >> $LOG_FILE
fi

exit $STATUS
